@@ -34,6 +34,23 @@ import ldap
 import ldap.modlist
 
 
+def groupExists(groupname):
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
+	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	
+	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	rv = _groupExists(db, groupname)
+	return rv
+
+
+def _groupExists(db, groupname):
+	sql = 'SELECT gidNumber FROM `jos_xgroups` WHERE `cn` = %s'
+	data = (groupname)
+	gidNumber = db.execSelectQueryScalar(sql, data)
+	return gidNumber
+
+
 def _del_jos_xgroups(db, name):
 	sql = "DELETE FROM jos_xgroups WHERE `CN`=%s "
 	data = (name)
